pub struct SpreadingGrassBlock {}Expand description
A structure implementing the spreading of grass blocks and its variants
Implementations
Sourceimpl SpreadingGrassBlock
impl SpreadingGrassBlock
fn can_stay_alive( state: BlockStateId, level: &Arc<World>, pos: BlockPos, ) -> bool
fn can_propagate(state: BlockStateId, level: &Arc<World>, pos: BlockPos) -> bool
Sourcepub fn random_tick(
own: BlockRef,
base: BlockRef,
state: BlockStateId,
world: &Arc<World>,
pos: BlockPos,
)
pub fn random_tick( own: BlockRef, base: BlockRef, state: BlockStateId, world: &Arc<World>, pos: BlockPos, )
Implements random tick for grass block and its variants (like mycelium) It allows blocks to spread to base blocks, and will make them disappear if there is any block ontop of them